# EventNotificationSubscription

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**filter** | [**EventNotificationSubscriptionFilter**](EventNotificationSubscriptionFilter.md) |  | [optional] 
**email_teams** | **list[str]** |  | [optional] 
**email_frequency_period** | **str** |  | [optional] 
**email_priority** | **str** |  | [optional] 
**email_digest_last_processed** | **datetime** |  | [optional] 
**email_digest_last_processed_event_auto_id** | **int** |  | [optional] 
**email_show_dates_in_time_zone_id** | **str** |  | [optional] 
**webhook_uri** | **str** |  | [optional] 
**webhook_teams** | **list[str]** |  | [optional] 
**webhook_timeout** | **str** |  | [optional] 
**webhook_header_key** | **str** |  | [optional] 
**webhook_header_value** | **str** |  | [optional] 
**webhook_last_processed** | **datetime** |  | [optional] 
**webhook_last_processed_event_auto_id** | **int** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


